diff mcabber/src/settings.c @ 1607:14690e624e9d

Add modules
author Myhailo Danylenko <isbear@ukrpost.net>
date Sun, 11 Oct 2009 16:01:52 +0200
parents dcd5d4c75199
children f9bf561e54d0
line wrap: on
line diff
--- a/mcabber/src/settings.c	Sun Oct 11 16:01:31 2009 +0200
+++ b/mcabber/src/settings.c	Sun Oct 11 16:01:52 2009 +0200
@@ -23,6 +23,7 @@
 #include <stdlib.h>
 #include <string.h>
 
+#include "config.h"
 #include "settings.h"
 #include "commands.h"
 #include "logprint.h"
@@ -176,12 +177,15 @@
       continue;
 
     // We only allow assignments line, except for commands "pgp", "source",
     // "color" and "otrpolicy", unless we're in runtime (i.e. not startup).
     if (runtime ||
         (strchr(line, '=') != NULL)        ||
         startswith(line, "pgp ", FALSE)    ||
         startswith(line, "source ", FALSE) ||
         startswith(line, "color ", FALSE)  ||
+#ifdef MODULES_ENABLE
+        startswith(line, "load ", FALSE)   ||
+#endif
         startswith(line, "otrpolicy", FALSE)) {
       // Only accept a few "safe" commands
       if (!runtime &&
@@ -191,6 +195,9 @@
           !startswith(line, "pgp ", FALSE)    &&
           !startswith(line, "source ", FALSE) &&
           !startswith(line, "color ", FALSE)  &&
+#ifdef MODULES_ENABLE
+          !startswith(line, "load ", FALSE)   &&
+#endif
           !startswith(line, "otrpolicy ", FALSE)) {
         scr_LogPrint(LPRINT_LOGNORM, "Error in configuration file (l. %d): "
                      "this command can't be used here", ln);
@@ -176,12 +177,15 @@
 
     // We only allow assignments line, except for commands "pgp", "source",
-    // "color" and "otrpolicy", unless we're in runtime (i.e. not startup).
+    // "color", "load" and "otrpolicy", unless we're in runtime (i.e. not startup).
     if (runtime ||
         (strchr(line, '=') != NULL)        ||